pub struct CommonSmartModuleOpt {
    pub filter: Option<String>,
    pub filter_map: Option<String>,
    pub map: Option<String>,
    pub array_map: Option<String>,
    pub aggregate: Option<String>,
    pub aggregate_initial_value: Option<String>,
    pub smart_module: Option<String>,
    pub smartmodule_parameters: Option<Vec<(String, String)>>,
}

Fields

filter: Option<String>

Path of filter smartmodule used as a pre-produce step if using source connector. If using sink connector this smartmodule will be used in consumer.

If the value is not a path to a file, it will be used to lookup a SmartModule by name

filter_map: Option<String>

Path of filter_map smartmodule used as a pre-produce step if using source connector. If using sink connector this smartmodule will be used in consumer.

If the value is not a path to a file, it will be used to lookup a SmartModule by name

map: Option<String>

Path of map smartmodule used as a pre-produce step if using source connector. If using sink connector this smartmodule will be used in consumer.

If the value is not a path to a file, it will be used to lookup a SmartModule by name

array_map: Option<String>

Path of arraymap smartmodule used as a pre-produce step if using source connector. If using sink connector this smartmodule will be used in consumer.

If the value is not a path to a file, it will be used to lookup a SmartModule by name

aggregate: Option<String>

Path of aggregate smartmodule used as a pre-produce step if using source connector. If using sink connector this smartmodule will be used in consumer.

If the value is not a path to a file, it will be used to lookup a SmartModule by name

aggregate_initial_value: Option<String>smart_module: Option<String>

Path of smartmodule used as a pre-produce step if using source connector. If using sink connector this smartmodule will be used in consumer.

If the value is not a path to a file, it will be used to lookup a SmartModule by name

smartmodule_parameters: Option<Vec<(String, String)>>

(Optional) Extra input parameters passed to the smartmodule module. They should be passed using key:value format.

It only accepts one key:value pair. In order to pass multiple pairs, call this option multiple times.

Example: –smartmodule-parameters key1:value –smartmodule-parameters key2:value